@@ -16,11 +16,6 @@
 
 
 import os
-def _get_umask():
-   oumask = os.umask(0)
-   os.umask(oumask)
-   return oumask
-_b4rpm_oumask = _get_umask()
 import rpm
 import types
 
@@ -31,15 +26,10 @@ import utils
 import tempfile
 
 class CreateRepoPackage(YumLocalPackage):
-    def __init__(self, ts, package, sumtype=None, external_data={}):
+    def __init__(self, ts, package, sumtype=None):
         YumLocalPackage.__init__(self, ts, package)
         if sumtype:
             self.checksum_type = sumtype
-        
-        if external_data:
-            for (key, val) in external_data.items():
-                setattr(self, key, val)
-                
 
     def _do_checksum(self):
         """return a checksum for a package:
@@ -54,7 +44,7 @@ class CreateRepoPackage(YumLocalPackage):
             return self._checksum
 
         # not using the cachedir
-        if not hasattr(self, '_cachedir') or not self._cachedir:
+        if not self._cachedir:
             self._checksum = misc.checksum(self.checksum_type, self.localpath)
             self._checksums = [(self.checksum_type, self._checksum, 1)]
             return self._checksum
@@ -65,8 +55,8 @@ class CreateRepoPackage(YumLocalPackage):
             t.append("".join(self.hdr[rpm.RPMTAG_SIGGPG]))
         if type(self.hdr[rpm.RPMTAG_SIGPGP]) is not types.NoneType:
             t.append("".join(self.hdr[rpm.RPMTAG_SIGPGP]))
-        if type(self.hdr[rpm.RPMTAG_HDRID]) is not types.NoneType:
-            t.append("".join(self.hdr[rpm.RPMTAG_HDRID]))
+        if type(self.hdr[rpm.RPMTAG_SHA1HEADER]) is not types.NoneType:
+            t.append("".join(self.hdr[rpm.RPMTAG_SHA1HEADER]))
 
         kcsum = misc.Checksums(checksums=[self.checksum_type])
         kcsum.update("".join(t))
@@ -80,7 +70,7 @@ class CreateRepoPackage(YumLocalPackage):
             csumo = open(csumfile, 'r')
             checksum = csumo.readline()
             csumo.close()
-
+            os.path.os.utime(csumfile, None)
         else:
             checksum = misc.checksum(self.checksum_type, self.localpath)
 
@@ -91,9 +81,6 @@ class CreateRepoPackage(YumLocalPackage):
                 csumo = os.fdopen(csumo, 'w', -1)
                 csumo.write(checksum)
                 csumo.close()
-                #  tempfile forces 002 ... we want to undo that, so that users
-                # can share the cache. BZ 833350.
-                os.chmod(tmpfilename, 0666 ^ _b4rpm_oumask)
                 os.rename(tmpfilename, csumfile)
             except:
                 pass
