@@ -19,8 +19,7 @@
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 import sys
-from lxml.etree import parse, tostring, Element
-
+from lxml.etree import parse, tostring, Element #pylint: disable=E0611
 
 class MdType(object):
     def __init__(self, namespace, rootelem):
