@@ -22,9 +22,8 @@
 import os
 import sys
 import re
-from optparse import OptionParser,SUPPRESS_HELP
+from optparse import OptionParser
 import time
-import errno
 
 import createrepo
 from createrepo import MDError
@@ -38,12 +37,6 @@ def parse_args(args, conf):
        Sanity check all the things being passed in.
     """
 
-    def_workers = os.nice(0)
-    if def_workers > 0:
-        def_workers = 1 # We are niced, so just use a single worker.
-    else:
-        def_workers = 0 # zoooom....
-
     _def   = yum.misc._default_checksums[0]
     _avail = yum.misc._available_checksums
     parser = OptionParser(version = "createrepo %s" % createrepo.__version__)
@@ -71,10 +64,8 @@ def parse_args(args, conf):
     parser.add_option("-C", "--checkts", default=False, action="store_true",
         help="check timestamps on files vs the metadata to see " \
            "if we need to update")
-    parser.add_option("-d", "--database", default=True, action="store_true",
-        help="create sqlite database files: now default, see --no-database to disable")
-    parser.add_option("--no-database", default=False, dest="nodatabase", action="store_true",
-        help="do not create sqlite dbs of metadata")
+    parser.add_option("-d", "--database", default=False, action="store_true",
+        help="create sqlite database files")
     # temporarily disabled
     #parser.add_option("--database-only", default=False, action="store_true",
     #  dest='database_only',
@@ -102,13 +93,11 @@ def parse_args(args, conf):
     parser.add_option("--changelog-limit", dest="changelog_limit",
         default=None, help="only import the last N changelog entries")
     parser.add_option("--unique-md-filenames", dest="unique_md_filenames",
-        help="include the file's checksum in the filename, helps with proxies (default)",
+        help="include the file's checksum in the filename, helps with proxies",
         default=True, action="store_true")
-    parser.add_option("--simple-md-filenames", dest="unique_md_filenames",
-        help="do not include the file's checksum in the filename",
-        action="store_false")
-    parser.add_option("--retain-old-md", default=0, type='int', dest='retain_old_md',
-        help="keep around the latest (by timestamp) N copies of the old repodata")
+    parser.add_option("--simple-md-filenames", dest="simple_md_filenames",
+        help="do not include the file's checksum in the filename, helps with proxies",
+        default=False, action="store_true")
     parser.add_option("--distro", default=[], action="append",
         help="distro tag and optional cpeid: --distro" "'cpeid,textname'")
     parser.add_option("--content", default=[], dest='content_tags',
@@ -117,8 +106,8 @@ def parse_args(args, conf):
         action="append", help="tags to describe the repository itself")
     parser.add_option("--revision", default=None,
         help="user-specified revision for this repository")
-    parser.add_option("--deltas", default=False, action="store_true",
-        help="create delta rpms and metadata")
+    #parser.add_option("--deltas", default=False, action="store_true",
+    #    help="create delta rpms and metadata")
     parser.add_option("--oldpackagedirs", default=[], dest="oldpackage_paths",
         action="append", help="paths to look for older pkgs to delta against")
     parser.add_option("--num-deltas", default=1, dest='num_deltas', type='int',
@@ -128,22 +117,6 @@ def parse_args(args, conf):
     parser.add_option("--max-delta-rpm-size", default=100000000,
         dest='max_delta_rpm_size', type='int',
         help="max size of an rpm that to run deltarpm against (in bytes)")
-    parser.add_option("--max-concurrent-delta-rpm-size", default=100000000,
-        dest='max_concurrent_delta_rpm_size', type='int',
-        help="max total payload size of concurrent deltarpm runs (in bytes)")
-    parser.add_option("--workers", default=def_workers,
-        dest='workers', type='int',
-        help="number of workers to spawn to read rpms")
-    parser.add_option("--delta-workers", default=1,
-        dest='delta_workers', type='int',
-        help="number of workers to spawn to create delta rpms")
-    parser.add_option("--xz", default=False,
-        action="store_true",
-        help=SUPPRESS_HELP)
-    parser.add_option("--compress-type", default='compat', dest="compress_type",
-        help="which compression type to use")
-        
-    
     (opts, argsleft) = parser.parse_args(args)
     if len(argsleft) > 1 and not opts.split:
         errorprint(_('Error: Only one directory allowed per run.'))
@@ -158,15 +131,6 @@ def parse_args(args, conf):
     else:
         directories = argsleft
 
-    if opts.workers >= 128:
-        errorprint(_('Warning: More than 128 workers is a lot. Limiting.'))
-        opts.workers = 128
-    if opts.delta_workers > opts.workers:
-        errorprint(_('Warning: Requested more delta workers than workers. This is insane. Limiting.'))
-        opts.delta_workers = opts.workers
-    if opts.max_concurrent_delta_rpm_size < opts.max_delta_rpm_size:
-        errorprint(_('Warning: max_concurrent_delta_rpm_size < max_delta_rpm_size - this will deadlock. Setting them to the same value.'))
-        opts.max_concurrent_delta_rpm_size = opts.max_delta_rpm_size
     if opts.sumtype == 'sha1':
         errorprint(_('Warning: It is more compatible to use sha instead of sha1'))
 
@@ -179,14 +143,9 @@ def parse_args(args, conf):
         errorprint(_('--split and --checkts options are mutually exclusive'))
         sys.exit(1)
 
-    if opts.nodatabase:
-        opts.database = False
-    
-    # xz is just a shorthand for compress_type
-    if opts.xz and opts.compress_type == 'compat':
-        opts.compress_type='xz'
-        
-        
+    if opts.simple_md_filenames:
+        opts.unique_md_filenames = False
+
     # let's switch over to using the conf object - put all the opts into it
     for opt in parser.option_list:
         if opt.dest is None: # this is fairly silly
@@ -211,15 +170,14 @@ def parse_args(args, conf):
 
     lst = []
     if conf.pkglist:
-        try:
-            for line in open(conf.pkglist):
-                line = line.strip()
-                if re.match('^\s*\#.*', line) or re.match('^\s*$', line):
-                    continue
-                lst.append(line)
-        except EnvironmentError, e:
-            print >> sys.stderr, e
-            sys.exit(1)
+        pfo = open(conf.pkglist, 'r')
+        for line in pfo.readlines():
+            line = line.strip()
+            if re.match('^\s*\#.*', line) or re.match('^\s*$', line):
+                continue
+            lst.append(line)
+        pfo.close()
+
     conf.pkglist = lst
 
     if conf.includepkg:
@@ -232,9 +190,6 @@ def parse_args(args, conf):
 
 class MDCallBack(object):
     """cli callback object for createrepo"""
-    def __init__(self):
-        self.__show_progress = os.isatty(1)
-
     def errorlog(self, thing):
         """error log output"""
         print >> sys.stderr, thing
@@ -245,9 +200,6 @@ class MDCallBack(object):
 
     def progress(self, item, current, total):
         """progress bar"""
-        
-        if not self.__show_progress:
-            return
         beg = "%*d/%d - " % (len(str(total)), current, total)
         left = 80 - len(beg)
         sys.stdout.write("\r%s%-*.*s" % (beg, left, left, item))
@@ -255,12 +207,6 @@ class MDCallBack(object):
 
 def main(args):
     """createrepo from cli main flow"""
-    try:
-        os.getcwd()
-    except OSError, e:
-        if e.errno != errno.ENOENT: raise
-        print ('No getcwd() access in current directory.')
-        sys.exit(1)
     start_st = time.time()
     conf = createrepo.MetaDataConfig()
     conf = parse_args(args, conf)
@@ -278,7 +224,6 @@ def main(args):
             if mdgen.checkTimeStamps():
                 if mdgen.conf.verbose:
                     print _('repo is up to date')
-                mdgen._cleanup_tmp_repodata_dir()
                 sys.exit(0)
 
         if conf.profile:
@@ -300,12 +245,6 @@ def main(args):
 
     except MDError, errormsg:
         errorprint(_('%s') % errormsg)
-        # cleanup
-        tmp = os.path.join(conf.outputdir, conf.tempdir)
-        if os.path.exists(tmp):
-            for name in os.listdir(tmp):
-                os.unlink(os.path.join(tmp, name))
-            os.rmdir(tmp)
         sys.exit(1)
 
 
